==> kubernetes-model-flowcontrol-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/PriorityLevelConfigurationSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PriorityLevelConfigurationSpecFluentImpl<A extends PriorityLevelConfigurationSpecFluent<A>> extends BaseFluent<A> implements PriorityLevelConfigurationSpecFluent<A>{
  public PriorityLevelConfigurationSpecFluentImpl() {
  }
  public PriorityLevelConfigurationSpecFluentImpl(PriorityLevelConfigurationSpec instance) {
    this.withLimited(instance.getLimited()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private LimitedPriorityLevelConfigurationBuilder limited;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitedPriorityLevelConfiguration getLimited() {
    return this.limited!=null ?this.limited.build():null;
  }
  public LimitedPriorityLevelConfiguration buildLimited() {
    return this.limited!=null ?this.limited.build():null;
  }
  public A withLimited(LimitedPriorityLevelConfiguration limited) {
    _visitables.get("limited").remove(this.limited);
    if (limited!=null){ this.limited= new LimitedPriorityLevelConfigurationBuilder(limited); _visitables.get("limited").add(this.limited);} else { this.limited = null; _visitables.get("limited").remove(this.limited); } return (A) this;
  }
  public Boolean hasLimited() {
    return this.limited != null;
  }
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimited() {
    return new PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl();
  }
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimitedLike(LimitedPriorityLevelConfiguration item) {
    return new PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl(item);
  }
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editLimited() {
    return withNewLimitedLike(getLimited());
  }
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimited() {
    return withNewLimitedLike(getLimited() != null ? getLimited(): new LimitedPriorityLevelConfigurationBuilder().build());
  }
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimitedLike(LimitedPriorityLevelConfiguration item) {
    return withNewLimitedLike(getLimited() != null ? getLimited(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PriorityLevelConfigurationSpecFluentImpl that = (PriorityLevelConfigurationSpecFluentImpl) o;
    if (limited != null ? !limited.equals(that.limited) :that.limited != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limited,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (limited != null) { sb.append("limited:"); sb.append(limited + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitedNestedImpl<N> extends LimitedPriorityLevelConfigurationFluentImpl<PriorityLevelConfigurationSpecFluent.LimitedNested<N>> implements PriorityLevelConfigurationSpecFluent.LimitedNested<N>,Nested<N>{
    LimitedNestedImpl(LimitedPriorityLevelConfiguration item) {
      this.builder = new LimitedPriorityLevelConfigurationBuilder(this, item);
    }
    LimitedNestedImpl() {
      this.builder = new LimitedPriorityLevelConfigurationBuilder(this);
    }
    LimitedPriorityLevelConfigurationBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationSpecFluentImpl.this.withLimited(builder.build());
    }
    public N endLimited() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/PriorityLevelConfigurationSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PriorityLevelConfigurationSpecFluentImpl<A extends PriorityLevelConfigurationSpecFluent<A>> extends BaseFluent<A> implements PriorityLevelConfigurationSpecFluent<A>{
  public PriorityLevelConfigurationSpecFluentImpl() {
  }
  public PriorityLevelConfigurationSpecFluentImpl(PriorityLevelConfigurationSpec instance) {
    if (instance != null) {
      this.withLimited(instance.getLimited());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private LimitedPriorityLevelConfigurationBuilder limited;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitedPriorityLevelConfiguration getLimited() {
    return this.limited!=null ?this.limited.build():null;
  }
  public LimitedPriorityLevelConfiguration buildLimited() {
    return this.limited!=null ?this.limited.build():null;
  }
  public A withLimited(LimitedPriorityLevelConfiguration limited) {
    _visitables.get("limited").remove(this.limited);
    if (limited!=null){ this.limited= new LimitedPriorityLevelConfigurationBuilder(limited); _visitables.get("limited").add(this.limited);} else { this.limited = null; _visitables.get("limited").remove(this.limited); } return (A) this;
  }
  public Boolean hasLimited() {
    return this.limited != null;
  }
  public PriorityLevelConfigurationSpecFluentImpl.LimitedNested<A> withNewLimited() {
    return new PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl();
  }
  public PriorityLevelConfigurationSpecFluentImpl.LimitedNested<A> withNewLimitedLike(LimitedPriorityLevelConfiguration item) {
    return new PriorityLevelConfigurationSpecFluentImpl.LimitedNestedImpl(item);
  }
  public PriorityLevelConfigurationSpecFluentImpl.LimitedNested<A> editLimited() {
    return withNewLimitedLike(getLimited());
  }
  public PriorityLevelConfigurationSpecFluentImpl.LimitedNested<A> editOrNewLimited() {
    return withNewLimitedLike(getLimited() != null ? getLimited(): new LimitedPriorityLevelConfigurationBuilder().build());
  }
  public PriorityLevelConfigurationSpecFluentImpl.LimitedNested<A> editOrNewLimitedLike(LimitedPriorityLevelConfiguration item) {
    return withNewLimitedLike(getLimited() != null ? getLimited(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PriorityLevelConfigurationSpecFluentImpl that = (PriorityLevelConfigurationSpecFluentImpl) o;
    if (!java.util.Objects.equals(limited, that.limited)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(limited,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (limited != null) { sb.append("limited:"); sb.append(limited + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitedNestedImpl<N> extends LimitedPriorityLevelConfigurationFluentImpl<PriorityLevelConfigurationSpecFluentImpl.LimitedNested<N>> implements PriorityLevelConfigurationSpecFluentImpl.LimitedNested<N>,Nested<N>{
    LimitedNestedImpl(LimitedPriorityLevelConfiguration item) {
      this.builder = new LimitedPriorityLevelConfigurationBuilder(this, item);
    }
    LimitedNestedImpl() {
      this.builder = new LimitedPriorityLevelConfigurationBuilder(this);
    }
    LimitedPriorityLevelConfigurationBuilder builder;
    public N and() {
      return (N) PriorityLevelConfigurationSpecFluentImpl.this.withLimited(builder.build());
    }
    public N endLimited() {
      return and();
    }
    
  }
  
}
